# coding: utf-8

# try:
from lxml import etree
# except ImportError:
#   try:
#     # Python 2.5
#     import xml.etree.cElementTree as etree
#   except ImportError:
#     try:
#       # Python 2.5
#       import xml.etree.ElementTree as etree
#     except ImportError:
#       try:
#         # normal cElementTree install
#         import cElementTree as etree
#       except ImportError:
#         try:
#           # normal ElementTree install
#           import elementtree.ElementTree as etree
#         except ImportError:
#           print("Failed to import ElementTree from any known place")


def create_element_recursively(parent, path):
    nodes = path.split('/')
    node = parent
    for n_str in nodes:
        n = node.find(n_str)
        if n is None:
            node = etree.SubElement(node, n_str)
        else:
            node = n
    return node



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['maxipago',
 'maxipago.managers',
 'maxipago.managers.payment',
 'maxipago.requesters',
 'maxipago.requesters.payment',
 'maxipago.resources',
 'maxipago.utils']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.18,<3.0']

setup_kwargs = {
    'name': 'rede-cotabest',
    'version': '1.0.2',
    'description': '',
    'long_description': None,
    'author': 'Fernando Coutinho',
    'author_email': 'fernando.coutinho@cotabest.com.br',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
